==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkPartitionSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkPartitionSpecFluentImpl<A extends NetworkPartitionSpecFluent<A>> extends BaseFluent<A> implements NetworkPartitionSpecFluent<A>{
  public NetworkPartitionSpecFluentImpl() {
  }
  public NetworkPartitionSpecFluentImpl(NetworkPartitionSpec instance) {
    this.withAcceptTcpFlags(instance.getAcceptTcpFlags()); 
    this.withDevice(instance.getDevice()); 
    this.withDirection(instance.getDirection()); 
    this.withHostname(instance.getHostname()); 
    this.withIpAddress(instance.getIpAddress()); 
    this.withIpProtocol(instance.getIpProtocol()); 
  }
  private String acceptTcpFlags;
  private String device;
  private String direction;
  private String hostname;
  private String ipAddress;
  private String ipProtocol;
  public String getAcceptTcpFlags() {
    return this.acceptTcpFlags;
  }
  public A withAcceptTcpFlags(String acceptTcpFlags) {
    this.acceptTcpFlags=acceptTcpFlags; return (A) this;
  }
  public Boolean hasAcceptTcpFlags() {
    return this.acceptTcpFlags != null;
  }
  public String getDevice() {
    return this.device;
  }
  public A withDevice(String device) {
    this.device=device; return (A) this;
  }
  public Boolean hasDevice() {
    return this.device != null;
  }
  public String getDirection() {
    return this.direction;
  }
  public A withDirection(String direction) {
    this.direction=direction; return (A) this;
  }
  public Boolean hasDirection() {
    return this.direction != null;
  }
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getIpAddress() {
    return this.ipAddress;
  }
  public A withIpAddress(String ipAddress) {
    this.ipAddress=ipAddress; return (A) this;
  }
  public Boolean hasIpAddress() {
    return this.ipAddress != null;
  }
  public String getIpProtocol() {
    return this.ipProtocol;
  }
  public A withIpProtocol(String ipProtocol) {
    this.ipProtocol=ipProtocol; return (A) this;
  }
  public Boolean hasIpProtocol() {
    return this.ipProtocol != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkPartitionSpecFluentImpl that = (NetworkPartitionSpecFluentImpl) o;
    if (acceptTcpFlags != null ? !acceptTcpFlags.equals(that.acceptTcpFlags) :that.acceptTcpFlags != null) return false;
    if (device != null ? !device.equals(that.device) :that.device != null) return false;
    if (direction != null ? !direction.equals(that.direction) :that.direction != null) return false;
    if (hostname != null ? !hostname.equals(that.hostname) :that.hostname != null) return false;
    if (ipAddress != null ? !ipAddress.equals(that.ipAddress) :that.ipAddress != null) return false;
    if (ipProtocol != null ? !ipProtocol.equals(that.ipProtocol) :that.ipProtocol != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(acceptTcpFlags,  device,  direction,  hostname,  ipAddress,  ipProtocol,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (acceptTcpFlags != null) { sb.append("acceptTcpFlags:"); sb.append(acceptTcpFlags + ","); }
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (direction != null) { sb.append("direction:"); sb.append(direction + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ipAddress != null) { sb.append("ipAddress:"); sb.append(ipAddress + ","); }
    if (ipProtocol != null) { sb.append("ipProtocol:"); sb.append(ipProtocol); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkPartitionSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkPartitionSpecFluentImpl<A extends NetworkPartitionSpecFluent<A>> extends BaseFluent<A> implements NetworkPartitionSpecFluent<A>{
  public NetworkPartitionSpecFluentImpl() {
  }
  public NetworkPartitionSpecFluentImpl(NetworkPartitionSpec instance) {
    if (instance != null) {
      this.withAcceptTcpFlags(instance.getAcceptTcpFlags());
      this.withDevice(instance.getDevice());
      this.withDirection(instance.getDirection());
      this.withHostname(instance.getHostname());
      this.withIpAddress(instance.getIpAddress());
      this.withIpProtocol(instance.getIpProtocol());
    }
  }
  private String acceptTcpFlags;
  private String device;
  private String direction;
  private String hostname;
  private String ipAddress;
  private String ipProtocol;
  public String getAcceptTcpFlags() {
    return this.acceptTcpFlags;
  }
  public A withAcceptTcpFlags(String acceptTcpFlags) {
    this.acceptTcpFlags=acceptTcpFlags; return (A) this;
  }
  public Boolean hasAcceptTcpFlags() {
    return this.acceptTcpFlags != null;
  }
  public String getDevice() {
    return this.device;
  }
  public A withDevice(String device) {
    this.device=device; return (A) this;
  }
  public Boolean hasDevice() {
    return this.device != null;
  }
  public String getDirection() {
    return this.direction;
  }
  public A withDirection(String direction) {
    this.direction=direction; return (A) this;
  }
  public Boolean hasDirection() {
    return this.direction != null;
  }
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getIpAddress() {
    return this.ipAddress;
  }
  public A withIpAddress(String ipAddress) {
    this.ipAddress=ipAddress; return (A) this;
  }
  public Boolean hasIpAddress() {
    return this.ipAddress != null;
  }
  public String getIpProtocol() {
    return this.ipProtocol;
  }
  public A withIpProtocol(String ipProtocol) {
    this.ipProtocol=ipProtocol; return (A) this;
  }
  public Boolean hasIpProtocol() {
    return this.ipProtocol != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkPartitionSpecFluentImpl that = (NetworkPartitionSpecFluentImpl) o;
    if (!java.util.Objects.equals(acceptTcpFlags, that.acceptTcpFlags)) return false;

    if (!java.util.Objects.equals(device, that.device)) return false;

    if (!java.util.Objects.equals(direction, that.direction)) return false;

    if (!java.util.Objects.equals(hostname, that.hostname)) return false;

    if (!java.util.Objects.equals(ipAddress, that.ipAddress)) return false;

    if (!java.util.Objects.equals(ipProtocol, that.ipProtocol)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(acceptTcpFlags,  device,  direction,  hostname,  ipAddress,  ipProtocol,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (acceptTcpFlags != null) { sb.append("acceptTcpFlags:"); sb.append(acceptTcpFlags + ","); }
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (direction != null) { sb.append("direction:"); sb.append(direction + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ipAddress != null) { sb.append("ipAddress:"); sb.append(ipAddress + ","); }
    if (ipProtocol != null) { sb.append("ipProtocol:"); sb.append(ipProtocol); }
    sb.append("}");
    return sb.toString();
  }
  
}
